componenttools.partition_components_once_by_prolated_durations_le_without_overhang
==================================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_once_by_prolated_durations_le_without_overhang.partition_components_once_by_prolated_durations_le_without_overhang
